@@ -27,7 +27,7 @@ def _prepare_ws(reponame, workspace, src_path, spec: SpecFile):
     tmpdir = mkdtemp(prefix=reponame + '_', dir=workspace)
     for edition in spec.data['editions']:
         edition_dirs.update({edition['name']: os.path.join(tmpdir, str(edition['name']))})
-        copy_tree(src_path, edition_dirs[edition['name']])
+        copy_tree(src_path, edition_dirs[edition['name']], preserve_symlinks=True)
     return tmpdir, edition_dirs
 
 
@@ -70,7 +70,8 @@ def _clean_ws(path):
 
 def build(reponame=None, repopath=None, workspace='/tmp',  # pylint: disable=R0913
           tarball_path=None, loglevel='ERROR',
-          clean_ws=True, master_branches=None, **args):
+          clean_ws=True, master_branches=None,
+          release_version=False, **args):
     """Moves sources to workspace inside of temporary directory. \
     Some operations over sources cant be proceed concurent(for exemple in pytest with xdist \
     plugin) that why each thread need is own tmp dir with sources. \
@@ -111,7 +112,7 @@ def build(reponame=None, repopath=None, workspace='/tmp',  # pylint: disable=R09
     ws_tepm_dir, work_dir_paths = _prepare_ws(reponame, workspace, repopath, spec)
 
     tarpath = _prepare_result_dir(workspace, tarball_path)
-    spec_processing(spec, work_dir_paths, workspace)
+    spec_processing(spec, work_dir_paths, workspace, release_version)
 
     out = dict(
         _pack(
