@@ -76,7 +76,7 @@ class SpecFile:
         return tar_except
 
 
-def spec_processing(spec: SpecFile, path, workspace):
+def spec_processing(spec: SpecFile, path, workspace, release_version):
     for edition in spec.data['editions']:
         if edition.get('preprocessors'):
             for x in edition['preprocessors']:
@@ -86,6 +86,10 @@ def spec_processing(spec: SpecFile, path, workspace):
                         command.extend(x['args'])
                     logging.info(check_output(command, cwd=path[edition['name']]).decode("utf-8"))
                 else:
-                    jinja_values = {'edition': edition['name']}
+                    if x['type'] == 'splitter':
+                        params = {'jinja_values': {'edition': edition['name'],
+                                                   'release_version': release_version}}
+                    else:
+                        params = {}
                     get_type_func(x['type'])(path[edition['name']], workspace,
-                                             edition=jinja_values, **x)
+                                             **params, **x)
